package worker

import (
	"sync"
)

type Pool struct {
	workers map[string]*Worker // key - model.Task.AmoID
	mux     sync.RWMutex
}

func NewPool() *Pool {
	return &Pool{workers: map[string]*Worker{}, mux: sync.RWMutex{}}
}

func (p *Pool) Set(amoID string, worker *Worker) {
	p.mux.Lock()
	p.workers[amoID] = worker
	p.mux.Unlock()
}

func (p *Pool) Get(amoID string) *Worker {
	p.mux.Lock()
	worker := p.workers[amoID]
	p.mux.Unlock()
	return worker
}

// Unset - останавливает воркер и удаляет его из пула.
func (p *Pool) Unset(amoID string) {
	p.mux.Lock()
	p.workers[amoID].Stop()
	delete(p.workers, amoID)
	p.mux.Unlock()
}
